@@ -1,13 +1,17 @@
 #!/bin/csh
 
+# This is the driver program for all the tests in the Testing
+# directory. There are sometimes problems with the *.sh files
+# not being executable, which is why I'm explicitly calling 
+# them with csh, so that they run regardless of file permissions
 
 foreach dir (combig count dice leftFisher \
              ll ll3 odds phi pmi rank rightFisher statistic tmi tmi3 \
              tscore x2 huge-count huge-combine sort-bigrams split-data) 
 
 	cd $dir
-	./normal-op.sh 
-	./error-handling.sh
+	csh ./normal-op.sh 
+	csh ./error-handling.sh
 	cd ..
 end
 
@@ -19,8 +23,8 @@ foreach dir (kocos)
 
 	    cd $subdir
 
-     	    ./normal-op.sh 
- 	    ./error-handling.sh
+     	    csh ./normal-op.sh 
+ 	    csh ./error-handling.sh
 
      	    cd ..
         end
